@@ -348,10 +348,12 @@ class PagSeguro(object):
         self.items.append(kwargs)
 
     def print_request(self, debug = False):
+
         self.payload_debug = json.loads(self.payload_debug)
-        self.payload_debug['payment_method']['card']['security_code'] = "xxx"
-        self.payload_debug['payment_method']['card']['number'] = "xxxxxx"
-        self.payload_debug = json.dumps(self.payload_debug)
+        if 'payment_method' in self.payload_debug:
+            self.payload_debug['payment_method']['card']['security_code'] = "xxx"
+            self.payload_debug['payment_method']['card']['number'] = "xxxxxx"
+
         if debug:
             print("------------------------------")
             print("URL:")
@@ -361,7 +363,7 @@ class PagSeguro(object):
             print(self.config.HEADERS)
             print("------------------------------")
             print("Body:")
-            print(json.dumps(json.loads(self.payload_debug), indent=4))
+            print(self.payload_debug)
             print("------------------------------")
             print("Response:")
             print(json.dumps(json.loads(self.response.text), indent=4))
